/****************************************************************************
** Meta object code from reading C++ file 'skanlite.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../skanlite-26.07.90/src/skanlite.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'skanlite.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8SkanliteE_t {};
} // unnamed namespace

template <> constexpr inline auto Skanlite::qt_create_metaobjectdata<qt_meta_tag_ZN8SkanliteE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Skanlite",
        "showSettingsDialog",
        "",
        "imageReady",
        "QImage",
        "image",
        "saveImage",
        "updateSaveProgress",
        "imageSaved",
        "QUrl",
        "url",
        "name",
        "success",
        "saveWindowSize",
        "saveScannerDevice",
        "saveScannerOptions",
        "defaultScannerOptions",
        "applyScannerOptions",
        "QMap<QString,QString>",
        "opts",
        "alertUser",
        "type",
        "strStatus",
        "buttonPressed",
        "optionName",
        "optionLabel",
        "pressed",
        "showHelp",
        "getScannerOptions",
        "setScannerOptions",
        "options",
        "ignoreSelection",
        "getDefaultScannerOptions",
        "saveScannerOptionsToProfile",
        "profile",
        "switchToProfile",
        "getDeviceName",
        "getSelection",
        "setSelection",
        "reselectScannerDevice",
        "updateWindowTitle",
        "deviceName",
        "deviceVendor",
        "deviceModel"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'showSettingsDialog'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'imageReady'
        QtMocHelpers::SlotData<void(const QImage &)>(3, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'saveImage'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateSaveProgress'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'imageSaved'
        QtMocHelpers::SlotData<void(const QUrl &, const QString &, bool)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { QMetaType::QString, 11 }, { QMetaType::Bool, 12 },
        }}),
        // Slot 'saveWindowSize'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'saveScannerDevice'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'saveScannerOptions'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'defaultScannerOptions'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'applyScannerOptions'
        QtMocHelpers::SlotData<void(const QMap<QString,QString> &)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Slot 'alertUser'
        QtMocHelpers::SlotData<void(int, const QString &)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 21 }, { QMetaType::QString, 22 },
        }}),
        // Slot 'buttonPressed'
        QtMocHelpers::SlotData<void(const QString &, const QString &, bool)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 25 }, { QMetaType::Bool, 26 },
        }}),
        // Slot 'showHelp'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'getScannerOptions'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setScannerOptions'
        QtMocHelpers::SlotData<void(const QStringList &, bool)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QStringList, 30 }, { QMetaType::Bool, 31 },
        }}),
        // Slot 'getDefaultScannerOptions'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'saveScannerOptionsToProfile'
        QtMocHelpers::SlotData<void(const QStringList &, const QString &, bool)>(33, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QStringList, 30 }, { QMetaType::QString, 34 }, { QMetaType::Bool, 31 },
        }}),
        // Slot 'switchToProfile'
        QtMocHelpers::SlotData<void(const QString &, bool)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 34 }, { QMetaType::Bool, 31 },
        }}),
        // Slot 'getDeviceName'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'getSelection'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setSelection'
        QtMocHelpers::SlotData<void(const QStringList &)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QStringList, 30 },
        }}),
        // Slot 'reselectScannerDevice'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateWindowTitle'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &)>(40, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 41 }, { QMetaType::QString, 42 }, { QMetaType::QString, 43 },
        }}),
        // Slot 'updateWindowTitle'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(40, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 41 }, { QMetaType::QString, 42 },
        }}),
        // Slot 'updateWindowTitle'
        QtMocHelpers::SlotData<void(const QString &)>(40, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 41 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Skanlite, qt_meta_tag_ZN8SkanliteE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Skanlite::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8SkanliteE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8SkanliteE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8SkanliteE_t>.metaTypes,
    nullptr
} };

void Skanlite::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Skanlite *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->showSettingsDialog(); break;
        case 1: _t->imageReady((*reinterpret_cast<std::add_pointer_t<QImage>>(_a[1]))); break;
        case 2: _t->saveImage(); break;
        case 3: _t->updateSaveProgress(); break;
        case 4: _t->imageSaved((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 5: _t->saveWindowSize(); break;
        case 6: _t->saveScannerDevice(); break;
        case 7: _t->saveScannerOptions(); break;
        case 8: _t->defaultScannerOptions(); break;
        case 9: _t->applyScannerOptions((*reinterpret_cast<std::add_pointer_t<QMap<QString,QString>>>(_a[1]))); break;
        case 10: _t->alertUser((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 11: _t->buttonPressed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 12: _t->showHelp(); break;
        case 13: _t->getScannerOptions(); break;
        case 14: _t->setScannerOptions((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 15: _t->getDefaultScannerOptions(); break;
        case 16: _t->saveScannerOptionsToProfile((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 17: _t->switchToProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 18: _t->getDeviceName(); break;
        case 19: _t->getSelection(); break;
        case 20: _t->setSelection((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 21: _t->reselectScannerDevice(); break;
        case 22: _t->updateWindowTitle((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 23: _t->updateWindowTitle((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 24: _t->updateWindowTitle((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *Skanlite::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Skanlite::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8SkanliteE_t>.strings))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int Skanlite::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 25)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 25;
    }
    return _id;
}
QT_WARNING_POP
