/********************************************************************************
** Form generated from reading UI file 'settings.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SETTINGS_H
#define UI_SETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_SkanliteSettings
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QLabel *label_7;
    QCheckBox *showB4Save;
    QLabel *label_6;
    QComboBox *saveModeCB;
    QFrame *line;
    QLabel *label;
    QLabel *label_2;
    QHBoxLayout *hboxLayout;
    QLineEdit *imgPrefix;
    QLabel *label_3;
    QComboBox *imgFormat;
    QLabel *label_4;
    QHBoxLayout *horizontalLayout;
    QCheckBox *setQuality;
    QFrame *imgQualityFrame;
    QHBoxLayout *hboxLayout1;
    QSlider *horizontalSlider;
    QSpinBox *imgQuality;
    QFrame *line_2;
    KUrlRequester *saveDirRequester;
    QGroupBox *generalGB;
    QGridLayout *gridLayout_2;
    QCheckBox *setPreviewDPI;
    QComboBox *previewDPI;
    QCheckBox *u_disableSelections;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *horizontalSpacer_2;
    QPushButton *revertOptions;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *SkanliteSettings)
    {
        if (SkanliteSettings->objectName().isEmpty())
            SkanliteSettings->setObjectName("SkanliteSettings");
        SkanliteSettings->resize(453, 370);
        verticalLayout = new QVBoxLayout(SkanliteSettings);
        verticalLayout->setObjectName("verticalLayout");
        groupBox = new QGroupBox(SkanliteSettings);
        groupBox->setObjectName("groupBox");
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName("gridLayout");
        label_7 = new QLabel(groupBox);
        label_7->setObjectName("label_7");
        label_7->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_7, 1, 0, 1, 1);

        showB4Save = new QCheckBox(groupBox);
        showB4Save->setObjectName("showB4Save");

        gridLayout->addWidget(showB4Save, 1, 1, 1, 1);

        label_6 = new QLabel(groupBox);
        label_6->setObjectName("label_6");
        label_6->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_6, 2, 0, 1, 1);

        saveModeCB = new QComboBox(groupBox);
        saveModeCB->addItem(QString());
        saveModeCB->addItem(QString());
        saveModeCB->setObjectName("saveModeCB");

        gridLayout->addWidget(saveModeCB, 2, 1, 1, 2);

        line = new QFrame(groupBox);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout->addWidget(line, 3, 0, 1, 3);

        label = new QLabel(groupBox);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label, 4, 0, 1, 1);

        label_2 = new QLabel(groupBox);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_2, 5, 0, 1, 1);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        imgPrefix = new QLineEdit(groupBox);
        imgPrefix->setObjectName("imgPrefix");

        hboxLayout->addWidget(imgPrefix);

        label_3 = new QLabel(groupBox);
        label_3->setObjectName("label_3");

        hboxLayout->addWidget(label_3);

        imgFormat = new QComboBox(groupBox);
        imgFormat->setObjectName("imgFormat");

        hboxLayout->addWidget(imgFormat);


        gridLayout->addLayout(hboxLayout, 5, 1, 1, 2);

        label_4 = new QLabel(groupBox);
        label_4->setObjectName("label_4");
        label_4->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_4, 7, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        setQuality = new QCheckBox(groupBox);
        setQuality->setObjectName("setQuality");

        horizontalLayout->addWidget(setQuality);

        imgQualityFrame = new QFrame(groupBox);
        imgQualityFrame->setObjectName("imgQualityFrame");
        imgQualityFrame->setEnabled(false);
        imgQualityFrame->setFrameShape(QFrame::NoFrame);
        imgQualityFrame->setFrameShadow(QFrame::Plain);
        imgQualityFrame->setLineWidth(0);
        hboxLayout1 = new QHBoxLayout(imgQualityFrame);
        hboxLayout1->setSpacing(6);
        hboxLayout1->setObjectName("hboxLayout1");
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        horizontalSlider = new QSlider(imgQualityFrame);
        horizontalSlider->setObjectName("horizontalSlider");
        horizontalSlider->setMaximum(100);
        horizontalSlider->setValue(85);
        horizontalSlider->setSliderPosition(85);
        horizontalSlider->setOrientation(Qt::Horizontal);

        hboxLayout1->addWidget(horizontalSlider);

        imgQuality = new QSpinBox(imgQualityFrame);
        imgQuality->setObjectName("imgQuality");
        imgQuality->setMaximum(100);
        imgQuality->setValue(85);

        hboxLayout1->addWidget(imgQuality);


        horizontalLayout->addWidget(imgQualityFrame);


        gridLayout->addLayout(horizontalLayout, 7, 1, 1, 2);

        line_2 = new QFrame(groupBox);
        line_2->setObjectName("line_2");
        line_2->setFrameShape(QFrame::Shape::HLine);
        line_2->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout->addWidget(line_2, 6, 0, 1, 3);

        saveDirRequester = new KUrlRequester(groupBox);
        saveDirRequester->setObjectName("saveDirRequester");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(saveDirRequester->sizePolicy().hasHeightForWidth());
        saveDirRequester->setSizePolicy(sizePolicy);
        saveDirRequester->setMode(KFile::Directory|KFile::ExistingOnly);

        gridLayout->addWidget(saveDirRequester, 4, 1, 1, 2);


        verticalLayout->addWidget(groupBox);

        generalGB = new QGroupBox(SkanliteSettings);
        generalGB->setObjectName("generalGB");
        gridLayout_2 = new QGridLayout(generalGB);
        gridLayout_2->setObjectName("gridLayout_2");
        setPreviewDPI = new QCheckBox(generalGB);
        setPreviewDPI->setObjectName("setPreviewDPI");

        gridLayout_2->addWidget(setPreviewDPI, 0, 1, 1, 1);

        previewDPI = new QComboBox(generalGB);
        previewDPI->addItem(QString());
        previewDPI->addItem(QString());
        previewDPI->addItem(QString());
        previewDPI->addItem(QString());
        previewDPI->addItem(QString());
        previewDPI->addItem(QString::fromUtf8("600"));
        previewDPI->setObjectName("previewDPI");
        previewDPI->setEnabled(false);
        previewDPI->setEditable(true);

        gridLayout_2->addWidget(previewDPI, 0, 2, 1, 1);

        u_disableSelections = new QCheckBox(generalGB);
        u_disableSelections->setObjectName("u_disableSelections");

        gridLayout_2->addWidget(u_disableSelections, 1, 1, 1, 2);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer, 0, 0, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_2, 0, 3, 1, 1);

        revertOptions = new QPushButton(generalGB);
        revertOptions->setObjectName("revertOptions");

        gridLayout_2->addWidget(revertOptions, 2, 1, 1, 2);


        verticalLayout->addWidget(generalGB);

        verticalSpacer = new QSpacerItem(1, 1, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

#if QT_CONFIG(shortcut)
        label_7->setBuddy(showB4Save);
        label_6->setBuddy(saveModeCB);
        label_2->setBuddy(imgPrefix);
        label_4->setBuddy(setQuality);
#endif // QT_CONFIG(shortcut)

        retranslateUi(SkanliteSettings);
        QObject::connect(setQuality, &QCheckBox::toggled, imgQualityFrame, &QFrame::setEnabled);
        QObject::connect(horizontalSlider, &QSlider::valueChanged, imgQuality, &QSpinBox::setValue);
        QObject::connect(imgQuality, &QSpinBox::valueChanged, horizontalSlider, &QSlider::setValue);
        QObject::connect(setPreviewDPI, &QCheckBox::toggled, previewDPI, &QComboBox::setEnabled);

        QMetaObject::connectSlotsByName(SkanliteSettings);
    } // setupUi

    void retranslateUi(QWidget *SkanliteSettings)
    {
        SkanliteSettings->setWindowTitle(tr2i18n("Settings", nullptr));
        groupBox->setTitle(tr2i18n("Image saving", nullptr));
        label_7->setText(tr2i18n("Preview before saving:", nullptr));
        showB4Save->setText(QString());
        label_6->setText(tr2i18n("Save mode:", nullptr));
        saveModeCB->setItemText(0, tr2i18n("Open the save dialog for every image", nullptr));
        saveModeCB->setItemText(1, tr2i18n("Open the save dialog for the first image only", nullptr));

        label->setText(tr2i18n("Save Location:", nullptr));
        label_2->setText(tr2i18n("Name && Format:", nullptr));
        imgPrefix->setText(tr2i18n("Image", nullptr));
        label_3->setText(tr2i18n("####.", nullptr));
        label_4->setText(tr2i18n("Specify save quality:", nullptr));
        setQuality->setText(QString());
        imgQuality->setSuffix(tr2i18n("%", nullptr));
        generalGB->setTitle(tr2i18n("General", nullptr));
        setPreviewDPI->setText(tr2i18n("Set preview resolution (DPI)", nullptr));
        previewDPI->setItemText(0, tr2i18n("50", nullptr));
        previewDPI->setItemText(1, tr2i18n("75", nullptr));
        previewDPI->setItemText(2, tr2i18n("100", nullptr));
        previewDPI->setItemText(3, tr2i18n("150", nullptr));
        previewDPI->setItemText(4, tr2i18n("300", nullptr));

        u_disableSelections->setText(tr2i18n("Disable automatic selections", nullptr));
        revertOptions->setText(tr2i18n("Revert scanner options to default values", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SkanliteSettings: public Ui_SkanliteSettings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SETTINGS_H

