/****************************************************************************
** Meta object code from reading C++ file 'DBusInterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../skanlite-26.07.90/src/DBusInterface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'DBusInterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13DBusInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto DBusInterface::qt_create_metaobjectdata<qt_meta_tag_ZN13DBusInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DBusInterface",
        "D-Bus Interface",
        "org.kde.skanlite",
        "requestedScan",
        "",
        "requestedPreview",
        "requestedScanCancel",
        "requestedGetScannerOptions",
        "requestedSetScannerOptions",
        "options",
        "ignoreSelection",
        "requestedDefaultScannerOptions",
        "requestedDeviceName",
        "requestedSaveScannerOptionsToProfile",
        "profile",
        "requestedSwitchToProfile",
        "requestedGetSelection",
        "requestedSetSelection",
        "imageSaved",
        "strFilename",
        "scanDone",
        "status",
        "strStatus",
        "userMessage",
        "type",
        "scanProgress",
        "percent",
        "buttonPressed",
        "optionName",
        "optionLabel",
        "pressed",
        "scan",
        "preview",
        "scanCancel",
        "getDeviceName",
        "getScannerOptions",
        "setScannerOptions",
        "getDefaultScannerOptions",
        "saveScannerOptionsToProfile",
        "saveCurrentScannerOptionsToProfile",
        "switchToProfile",
        "getSelection",
        "setSelection"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'requestedScan'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestedPreview'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestedScanCancel'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestedGetScannerOptions'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestedSetScannerOptions'
        QtMocHelpers::SignalData<void(const QStringList &, bool)>(8, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 9 }, { QMetaType::Bool, 10 },
        }}),
        // Signal 'requestedDefaultScannerOptions'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestedDeviceName'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestedSaveScannerOptionsToProfile'
        QtMocHelpers::SignalData<void(const QStringList &, const QString &, bool)>(13, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 9 }, { QMetaType::QString, 14 }, { QMetaType::Bool, 10 },
        }}),
        // Signal 'requestedSwitchToProfile'
        QtMocHelpers::SignalData<void(const QString &, bool)>(15, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 }, { QMetaType::Bool, 10 },
        }}),
        // Signal 'requestedGetSelection'
        QtMocHelpers::SignalData<void()>(16, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestedSetSelection'
        QtMocHelpers::SignalData<void(const QStringList &)>(17, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 9 },
        }}),
        // Signal 'imageSaved'
        QtMocHelpers::SignalData<void(const QString &)>(18, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 19 },
        }}),
        // Signal 'scanDone'
        QtMocHelpers::SignalData<void(int, const QString &)>(20, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 21 }, { QMetaType::QString, 22 },
        }}),
        // Signal 'userMessage'
        QtMocHelpers::SignalData<void(int, const QString &)>(23, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 24 }, { QMetaType::QString, 22 },
        }}),
        // Signal 'scanProgress'
        QtMocHelpers::SignalData<void(int)>(25, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 26 },
        }}),
        // Signal 'buttonPressed'
        QtMocHelpers::SignalData<void(const QString &, const QString &, bool)>(27, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 28 }, { QMetaType::QString, 29 }, { QMetaType::Bool, 30 },
        }}),
        // Slot 'scan'
        QtMocHelpers::SlotData<void()>(31, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'preview'
        QtMocHelpers::SlotData<void()>(32, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'scanCancel'
        QtMocHelpers::SlotData<void()>(33, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'getDeviceName'
        QtMocHelpers::SlotData<QString()>(34, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'getScannerOptions'
        QtMocHelpers::SlotData<QStringList()>(35, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QStringList),
        // Slot 'setScannerOptions'
        QtMocHelpers::SlotData<void(const QStringList &, bool)>(36, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QStringList, 9 }, { QMetaType::Bool, 10 },
        }}),
        // Slot 'setScannerOptions'
        QtMocHelpers::SlotData<void(const QStringList &)>(36, 4, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QStringList, 9 },
        }}),
        // Slot 'getDefaultScannerOptions'
        QtMocHelpers::SlotData<QStringList()>(37, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QStringList),
        // Slot 'saveScannerOptionsToProfile'
        QtMocHelpers::SlotData<void(const QStringList &, const QString &, bool)>(38, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QStringList, 9 }, { QMetaType::QString, 14 }, { QMetaType::Bool, 10 },
        }}),
        // Slot 'saveScannerOptionsToProfile'
        QtMocHelpers::SlotData<void(const QStringList &, const QString &)>(38, 4, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QStringList, 9 }, { QMetaType::QString, 14 },
        }}),
        // Slot 'saveScannerOptionsToProfile'
        QtMocHelpers::SlotData<void(const QStringList &)>(38, 4, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QStringList, 9 },
        }}),
        // Slot 'saveCurrentScannerOptionsToProfile'
        QtMocHelpers::SlotData<void(const QString &, bool)>(39, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 14 }, { QMetaType::Bool, 10 },
        }}),
        // Slot 'saveCurrentScannerOptionsToProfile'
        QtMocHelpers::SlotData<void(const QString &)>(39, 4, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'saveCurrentScannerOptionsToProfile'
        QtMocHelpers::SlotData<void()>(39, 4, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'switchToProfile'
        QtMocHelpers::SlotData<void(const QString &, bool)>(40, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 14 }, { QMetaType::Bool, 10 },
        }}),
        // Slot 'switchToProfile'
        QtMocHelpers::SlotData<void(const QString &)>(40, 4, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'switchToProfile'
        QtMocHelpers::SlotData<void()>(40, 4, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'getSelection'
        QtMocHelpers::SlotData<QStringList()>(41, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QStringList),
        // Slot 'setSelection'
        QtMocHelpers::SlotData<void(const QStringList &)>(42, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QStringList, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<DBusInterface, qt_meta_tag_ZN13DBusInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DBusInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DBusInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DBusInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13DBusInterfaceE_t>.metaTypes,
    nullptr
} };

void DBusInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DBusInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->requestedScan(); break;
        case 1: _t->requestedPreview(); break;
        case 2: _t->requestedScanCancel(); break;
        case 3: _t->requestedGetScannerOptions(); break;
        case 4: _t->requestedSetScannerOptions((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 5: _t->requestedDefaultScannerOptions(); break;
        case 6: _t->requestedDeviceName(); break;
        case 7: _t->requestedSaveScannerOptionsToProfile((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 8: _t->requestedSwitchToProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 9: _t->requestedGetSelection(); break;
        case 10: _t->requestedSetSelection((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 11: _t->imageSaved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->scanDone((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 13: _t->userMessage((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 14: _t->scanProgress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 15: _t->buttonPressed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 16: _t->scan(); break;
        case 17: _t->preview(); break;
        case 18: _t->scanCancel(); break;
        case 19: { QString _r = _t->getDeviceName();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 20: { QStringList _r = _t->getScannerOptions();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 21: _t->setScannerOptions((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 22: _t->setScannerOptions((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 23: { QStringList _r = _t->getDefaultScannerOptions();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 24: _t->saveScannerOptionsToProfile((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 25: _t->saveScannerOptionsToProfile((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 26: _t->saveScannerOptionsToProfile((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 27: _t->saveCurrentScannerOptionsToProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 28: _t->saveCurrentScannerOptionsToProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 29: _t->saveCurrentScannerOptionsToProfile(); break;
        case 30: _t->switchToProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 31: _t->switchToProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 32: _t->switchToProfile(); break;
        case 33: { QStringList _r = _t->getSelection();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 34: _t->setSelection((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DBusInterface::*)()>(_a, &DBusInterface::requestedScan, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusInterface::*)()>(_a, &DBusInterface::requestedPreview, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusInterface::*)()>(_a, &DBusInterface::requestedScanCancel, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusInterface::*)()>(_a, &DBusInterface::requestedGetScannerOptions, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusInterface::*)(const QStringList & , bool )>(_a, &DBusInterface::requestedSetScannerOptions, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusInterface::*)()>(_a, &DBusInterface::requestedDefaultScannerOptions, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusInterface::*)()>(_a, &DBusInterface::requestedDeviceName, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusInterface::*)(const QStringList & , const QString & , bool )>(_a, &DBusInterface::requestedSaveScannerOptionsToProfile, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusInterface::*)(const QString & , bool )>(_a, &DBusInterface::requestedSwitchToProfile, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusInterface::*)()>(_a, &DBusInterface::requestedGetSelection, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusInterface::*)(const QStringList & )>(_a, &DBusInterface::requestedSetSelection, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusInterface::*)(const QString & )>(_a, &DBusInterface::imageSaved, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusInterface::*)(int , const QString & )>(_a, &DBusInterface::scanDone, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusInterface::*)(int , const QString & )>(_a, &DBusInterface::userMessage, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusInterface::*)(int )>(_a, &DBusInterface::scanProgress, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusInterface::*)(const QString & , const QString & , bool )>(_a, &DBusInterface::buttonPressed, 15))
            return;
    }
}

const QMetaObject *DBusInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DBusInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DBusInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DBusInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 35)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 35;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 35)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 35;
    }
    return _id;
}

// SIGNAL 0
void DBusInterface::requestedScan()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DBusInterface::requestedPreview()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void DBusInterface::requestedScanCancel()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void DBusInterface::requestedGetScannerOptions()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void DBusInterface::requestedSetScannerOptions(const QStringList & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void DBusInterface::requestedDefaultScannerOptions()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void DBusInterface::requestedDeviceName()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void DBusInterface::requestedSaveScannerOptionsToProfile(const QStringList & _t1, const QString & _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2, _t3);
}

// SIGNAL 8
void DBusInterface::requestedSwitchToProfile(const QString & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void DBusInterface::requestedGetSelection()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void DBusInterface::requestedSetSelection(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void DBusInterface::imageSaved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void DBusInterface::scanDone(int _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1, _t2);
}

// SIGNAL 13
void DBusInterface::userMessage(int _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1, _t2);
}

// SIGNAL 14
void DBusInterface::scanProgress(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void DBusInterface::buttonPressed(const QString & _t1, const QString & _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
