/********************************************************************************
** Form generated from reading UI file 'SaveLocation.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SAVELOCATION_H
#define UI_SAVELOCATION_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_SaveLocation
{
public:
    QVBoxLayout *verticalLayout;
    QFormLayout *formLayout;
    QLabel *locationLabel;
    QHBoxLayout *horizontalLayout;
    KUrlRequester *u_urlRequester;
    QLabel *namePrefixLabel;
    QHBoxLayout *hboxLayout;
    QLineEdit *u_imgPrefix;
    QLabel *numberLabel;
    QComboBox *u_imgFormat;
    QLabel *numStartFromLabel;
    QHBoxLayout *horizontalLayout_4;
    QSpinBox *u_numStartFrom;
    QSpacerItem *horizontalSpacer;
    QLabel *u_resultLabel;
    QLabel *u_resultValue;
    QDialogButtonBox *u_dialogButtonBox;

    void setupUi(QDialog *SaveLocation)
    {
        if (SaveLocation->objectName().isEmpty())
            SaveLocation->setObjectName("SaveLocation");
        SaveLocation->resize(452, 178);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(SaveLocation->sizePolicy().hasHeightForWidth());
        SaveLocation->setSizePolicy(sizePolicy);
        verticalLayout = new QVBoxLayout(SaveLocation);
        verticalLayout->setObjectName("verticalLayout");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        locationLabel = new QLabel(SaveLocation);
        locationLabel->setObjectName("locationLabel");
        locationLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, locationLabel);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        u_urlRequester = new KUrlRequester(SaveLocation);
        u_urlRequester->setObjectName("u_urlRequester");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(u_urlRequester->sizePolicy().hasHeightForWidth());
        u_urlRequester->setSizePolicy(sizePolicy1);
        u_urlRequester->setMode(KFile::Directory|KFile::ExistingOnly);

        horizontalLayout->addWidget(u_urlRequester);


        formLayout->setLayout(0, QFormLayout::ItemRole::FieldRole, horizontalLayout);

        namePrefixLabel = new QLabel(SaveLocation);
        namePrefixLabel->setObjectName("namePrefixLabel");
        namePrefixLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, namePrefixLabel);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        u_imgPrefix = new QLineEdit(SaveLocation);
        u_imgPrefix->setObjectName("u_imgPrefix");

        hboxLayout->addWidget(u_imgPrefix);

        numberLabel = new QLabel(SaveLocation);
        numberLabel->setObjectName("numberLabel");

        hboxLayout->addWidget(numberLabel);

        u_imgFormat = new QComboBox(SaveLocation);
        u_imgFormat->setObjectName("u_imgFormat");

        hboxLayout->addWidget(u_imgFormat);


        formLayout->setLayout(1, QFormLayout::ItemRole::FieldRole, hboxLayout);

        numStartFromLabel = new QLabel(SaveLocation);
        numStartFromLabel->setObjectName("numStartFromLabel");
        numStartFromLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, numStartFromLabel);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        u_numStartFrom = new QSpinBox(SaveLocation);
        u_numStartFrom->setObjectName("u_numStartFrom");
        u_numStartFrom->setMinimum(0);
        u_numStartFrom->setMaximum(999999);

        horizontalLayout_4->addWidget(u_numStartFrom);

        horizontalSpacer = new QSpacerItem(168, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer);


        formLayout->setLayout(2, QFormLayout::ItemRole::FieldRole, horizontalLayout_4);

        u_resultLabel = new QLabel(SaveLocation);
        u_resultLabel->setObjectName("u_resultLabel");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, u_resultLabel);

        u_resultValue = new QLabel(SaveLocation);
        u_resultValue->setObjectName("u_resultValue");
        u_resultValue->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, u_resultValue);


        verticalLayout->addLayout(formLayout);

        u_dialogButtonBox = new QDialogButtonBox(SaveLocation);
        u_dialogButtonBox->setObjectName("u_dialogButtonBox");
        u_dialogButtonBox->setOrientation(Qt::Horizontal);
        u_dialogButtonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(u_dialogButtonBox);


        retranslateUi(SaveLocation);
        QObject::connect(u_dialogButtonBox, &QDialogButtonBox::accepted, SaveLocation, qOverload<>(&QDialog::accept));
        QObject::connect(u_dialogButtonBox, &QDialogButtonBox::rejected, SaveLocation, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(SaveLocation);
    } // setupUi

    void retranslateUi(QDialog *SaveLocation)
    {
        SaveLocation->setWindowTitle(tr2i18n("Save Location", nullptr));
        locationLabel->setText(tr2i18n("Save Location:", nullptr));
        namePrefixLabel->setText(tr2i18n("Name & Format:", nullptr));
        u_imgPrefix->setText(QString());
        numberLabel->setText(tr2i18n("####.", nullptr));
        numStartFromLabel->setText(tr2i18n("Start numbering from:", nullptr));
        u_resultLabel->setText(tr2i18n("Example:", nullptr));
        u_resultValue->setText(tr2i18n("/home/joe/example.png", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SaveLocation: public Ui_SaveLocation {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SAVELOCATION_H

